==> wm-react-native-components-0.0.97.tgz: package/WMButton.js <==
import React, {Component, PureComponent} from 'react';

import PropTypes from 'prop-types';

import {
    TouchableWithoutFeedback,
    View,
    Text,
    Image,
    StyleSheet,
    ColorPropType,
} from 'react-native';

import {
    ImageStylePropTypes,
    StyleSheetPropType,
    ViewStylePropTypes,
} from './RNExt';

const stylePropType = StyleSheetPropType(ViewStylePropTypes);
const imageStylePropTypes = StyleSheetPropType(ImageStylePropTypes);

export default class WMButton extends PureComponent {

    static propTypes = {
        enable: PropTypes.bool, //是否启用
        normalBackgroundColor: ColorPropType,   //启用状态下的背景色
        disabledBackgroundColor: ColorPropType, //禁用状态下的背景色
        normalBorderColor: ColorPropType, //启用状态下的 border color
        disabledBorderColor: ColorPropType, //禁用状态下的 border color
        fontSize: PropTypes.number, //字体大小
        normalTxtColor: ColorPropType, //启用状态下的字体颜色
        disabledTxtColor: ColorPropType, //禁用状态下的字体颜色
        title: PropTypes.string,    //文案
        image: Image.propTypes.source, //Image.source
        resizeMode: Image.propTypes.resizeMode, //Image resizeMode
        imageStyle: imageStylePropTypes,  //图片style
        style: stylePropType,  //container style
    }

    static defaultProps = {
        enable: true,
        normalBackgroundColor: '#ffffff',
        disabledBackgroundColor: '#999999',
        normalBorderColor:'#ffffff',
        disabledBorderColor:'#999999',
        fontSize: 16,
        normalTxtColor:'#000000',
        disabledTxtColor:'#000000',
        title: null
    }

    constructor(props) {
        super(props);

        this.state = {
            enable: props.enable
        }
    }

    setEnable = (enable) => {
        this.setState({
            enable: enable
        });
    }

    _onPress = (e) => {
        if (this.state.enable) {
            const { onPress, target } = this.props;
            onPress && onPress(e, target);
        }
    }

    render() {
        let backgroundColor = this.state.enable ? this.props.normalBackgroundColor : this.props.disabledBackgroundColor;
        let borderColor = this.state.enable ? this.props.normalBorderColor : this.props.disabledBorderColor;
        let txtColor = this.state.enable ? this.props.normalTxtColor : this.props.disabledTxtColor;
        let image = null;
        if (this.props.image) {
            image = <Image resizeMode={this.props.resizeMode || 'contain'} source={this.props.image} style={this.props.imageStyle} />
        }
        let text = null;
        if (this.props.title) {
            text = (
                <Text numberOfLines={1} style={{fontSize: this.props.fontSize, color: txtColor}}>{this.props.title}</Text>
            );
        }
        return (
            <View pointerEvents={'box-none'} style={[styles.container, this.props.style, {backgroundColor: backgroundColor, borderColor: borderColor}]}>
                <TouchableWithoutFeedback onPress={this._onPress}>
                    <View style={styles.contentContainer}>
                        {image}
                        {text}
                    </View>
                </TouchableWithoutFeedback>
            </View>
        );
    }
}

const styles = StyleSheet.create({
    container: {
        borderRadius: 5,
        height:40,
    },
    contentContainer: {
        flex:1,
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center'
    },
});

==> wm-react-native-components-0.0.100.tgz: package/WMButton.js <==
import React, {Component, PureComponent} from 'react';

import PropTypes from 'prop-types';

import {
    TouchableWithoutFeedback,
    View,
    Text,
    Image,
    StyleSheet,
    ColorPropType,
} from 'react-native';

import {
    ImageStylePropTypes,
    StyleSheetPropType,
    ViewStylePropTypes,
} from './RNExt';

const stylePropType = StyleSheetPropType(ViewStylePropTypes);
const imageStylePropTypes = StyleSheetPropType(ImageStylePropTypes);

export default class WMButton extends PureComponent {

    static propTypes = {
        enable: PropTypes.bool, //是否启用
        normalBackgroundColor: ColorPropType,   //启用状态下的背景色
        disabledBackgroundColor: ColorPropType, //禁用状态下的背景色
        normalBorderColor: ColorPropType, //启用状态下的 border color
        disabledBorderColor: ColorPropType, //禁用状态下的 border color
        fontSize: PropTypes.number, //字体大小
        normalTxtColor: ColorPropType, //启用状态下的字体颜色
        disabledTxtColor: ColorPropType, //禁用状态下的字体颜色
        title: PropTypes.string,    //文案
        image: Image.propTypes.source, //Image.source
        resizeMode: Image.propTypes.resizeMode, //Image resizeMode
        imageStyle: imageStylePropTypes,  //图片style
        style: stylePropType,  //container style
    }

    static defaultProps = {
        enable: true,
        normalBackgroundColor: '#ffffff',
        disabledBackgroundColor: '#999999',
        normalBorderColor:'#ffffff',
        disabledBorderColor:'#999999',
        fontSize: 16,
        normalTxtColor:'#000000',
        disabledTxtColor:'#000000',
        title: null
    }

    constructor(props) {
        super(props);

        this.state = {
            enable: props.enable
        }
    }

    setEnable = (enable) => {
        this.setState({
            enable: enable
        });
    }

    _onPress = (e) => {
        if (this.state.enable) {
            const { onPress, onPress2, target } = this.props;
            onPress && onPress();
            onPress2 && onPress2(e, target);
        }
    }

    render() {
        let backgroundColor = this.state.enable ? this.props.normalBackgroundColor : this.props.disabledBackgroundColor;
        let borderColor = this.state.enable ? this.props.normalBorderColor : this.props.disabledBorderColor;
        let txtColor = this.state.enable ? this.props.normalTxtColor : this.props.disabledTxtColor;
        let image = null;
        if (this.props.image) {
            image = <Image resizeMode={this.props.resizeMode || 'contain'} source={this.props.image} style={this.props.imageStyle} />
        }
        let text = null;
        if (this.props.title) {
            text = (
                <Text numberOfLines={1} style={{fontSize: this.props.fontSize, color: txtColor}}>{this.props.title}</Text>
            );
        }
        return (
            <View pointerEvents={'box-none'} style={[styles.container, this.props.style, {backgroundColor: backgroundColor, borderColor: borderColor}]}>
                <TouchableWithoutFeedback onPress={this._onPress}>
                    <View style={styles.contentContainer}>
                        {image}
                        {text}
                    </View>
                </TouchableWithoutFeedback>
            </View>
        );
    }
}

const styles = StyleSheet.create({
    container: {
        borderRadius: 5,
        height:40,
    },
    contentContainer: {
        flex:1,
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center'
    },
});
